==> pyhiveapi-0.3.5-py2.py3-none-any.whl: pyhiveapi/hub.py <==
"""Hive Hub Module."""

from .helper.const import HIVETOHA


class Hub:
    """Hive Hub Code."""

    hubType = "Hub"
    logType = "Sensor"

    def __init__(self, session=None):
        """Initialise hub."""
        self.session = session

    def hub_smoke(self, device):
        """Get the online status of the Hive hub."""
        state = None
        final = None

        try:
            data = self.session.self.session.data.products[device["hiveID"]]
            state = data["props"]["sensors"]["SMOKE_CO"]["active"]
            final = HIVETOHA[self.hubType]["Smoke"].get(state, state)
        except KeyError as e:
            self.session.log.error(e)

        return final

    def hub_dog_bark(self, device):
        """Get the online status of the Hive hub."""
        state = None
        final = None

        try:
            data = self.session.self.session.data.products[device["hiveID"]]
            state = data["props"]["sensors"]["DOG_BARK"]["active"]
            final = HIVETOHA[self.hubType]["Dog"].get(state, state)
        except KeyError as e:
            self.session.log.error(e)

        return final

    def hub_glass(self, device):
        """Get the glass detected status from the Hive hub."""
        state = None
        final = None

        try:
            data = self.session.self.session.data.products[device["hiveID"]]
            state = data["props"]["sensors"]["GLASS_BREAK"]["active"]
            final = HIVETOHA[self.hubType]["Glass"].get(state, state)
        except KeyError as e:
            self.session.log.error(e)

        return final

==> pyhiveapi-0.3.6-py2.py3-none-any.whl: pyhiveapi/hub.py <==
"""Hive Hub Module."""

from .helper.const import HIVETOHA


class Hub:
    """Hive Hub Code."""

    hubType = "Hub"
    logType = "Sensor"

    def __init__(self, session=None):
        """Initialise hub."""
        self.session = session

    def hubSmoke(self, device):
        """Get the online status of the Hive hub."""
        state = None
        final = None

        try:
            data = self.session.data.products[device["hiveID"]]
            state = data["props"]["sensors"]["SMOKE_CO"]["active"]
            final = HIVETOHA[self.hubType]["Smoke"].get(state, state)
        except KeyError as e:
            self.session.log.error(e)

        return final

    def hubDogBark(self, device):
        """Get the online status of the Hive hub."""
        state = None
        final = None

        try:
            data = self.session.data.products[device["hiveID"]]
            state = data["props"]["sensors"]["DOG_BARK"]["active"]
            final = HIVETOHA[self.hubType]["Dog"].get(state, state)
        except KeyError as e:
            self.session.log.error(e)

        return final

    def hubGlass(self, device):
        """Get the glass detected status from the Hive hub."""
        state = None
        final = None

        try:
            data = self.session.data.products[device["hiveID"]]
            state = data["props"]["sensors"]["GLASS_BREAK"]["active"]
            final = HIVETOHA[self.hubType]["Glass"].get(state, state)
        except KeyError as e:
            self.session.log.error(e)

        return final
